@@ -11,14 +11,13 @@ test_that("correctness of calculation",  {
   expect_is(pcoaRes, "pcoadata")
 
 
-  names(pcoa_cmdscale$eig) = names(pcoaRes$eigenvalues)
-  expect_equal( pcoaRes$eigenvalues, pcoa_cmdscale$eig[1:pcoaRes$rank])
+  expect_equal(pcoaRes$eigenvalues, pcoa_cmdscale$eig)
 
   expect_equal(pcoaRes$distMethod, "euclidean")
 
-  expect_equal(paste(pcoaRes$objects$scores[1:5,1], collapse = ""), "-2.58440793355984-2.49362396964195-2.61614101238806-2.69556703915561-1.71592266465019")
+  expect_equal(paste(round(pcoaRes$objects$scores[1:5,1], digits = 4), collapse = ""), "-2.5844-2.4936-2.6161-2.6956-1.7159")
 
-  expect_equal(paste(pcoaRes$groupMeans[1:3,2], collapse = ""), "-2.287717094199942.66900327656659NA")
+  expect_equal(paste(round(pcoaRes$groupMeans[1:3,2], digits = 4), collapse = ""), "-2.28772.669NA")
 
 
   pcoaRes = pcoa.calc(imp, distMethod = "jaccard")
