@@ -3,7 +3,7 @@ context("plotCharacters.cdadata_scatter")
 # locally suppress warnings
 data(centaurea)
 centaurea = suppressWarnings(naMeanSubst(centaurea))
-centaurea = deletePopulation(centaurea, populationName = c("LIP", "PREL"))
+centaurea = removePopulation(centaurea, populationName = c("LIP", "PREL"))
 
 cdaRes = cda.calc(centaurea)
 
